@@ -197,7 +197,7 @@ class FlaviusCreditAdd(FlaviusBase):
     Flaviusの支払明細を追加するAPI
     """
     def __init__(self):
-        super(FlaviusCreditAdd, self).__init__(search_url='', create_url='', update_url=conf.FLAVIUS_API_CREDIT_ADD,
+        super(FlaviusCreditAdd, self).__init__(search_url='', create_url=conf.FLAVIUS_API_CREDIT_ADD, update_url='',
                                                delete_url='')
 
 
